import click
from ecsclient.common.exceptions import ECSClientException

from .._util.exceptions import EcsmgmtClickException
from .._util.echo import success


@click.command()
@click.argument('bucket-name', type=click.STRING)
@click.option('-n', '--namespace', type=click.STRING, show_default=True)
@click.pass_obj
def cli(obj, bucket_name, namespace):
    """Delete bucket
    """
    client = obj['client']

    try:
        client.bucket.delete(bucket_name=bucket_name, namespace=namespace)
        success(f'deleted bucket "{bucket_name}" in namespace "{namespace}"')
    except ECSClientException as e:
        raise EcsmgmtClickException(e.message)



import os.path

import click
import yaml


def build_namespace_options(parent_command, ctx, namespace):
    command_tree = {}
    for command in parent_command.list_commands(ctx):
        cmd = parent_command.get_command(ctx, command)
        if isinstance(cmd, click.MultiCommand):
            command_tree[command] = build_namespace_options(cmd, ctx, namespace)
        else:
            if cmd is None:
                continue
            if 'namespace' in [param.name for param in cmd.params if isinstance(param, click.Option)]:
                command_tree[command] = {'namespace': namespace}
    return command_tree


def load_config(ctx, param, config_path):
    configpath = os.path.abspath(os.path.expanduser(config_path))

    try:
        with open(configpath, 'r') as infile:
            config = yaml.safe_load(infile.read())
    except FileNotFoundError:
        return

    options = dict(config.pop('defaults', {}))

    try:
        namespace_options = build_namespace_options(ctx.command, ctx, options['namespace'])
        options.update(namespace_options)
    except KeyError:
        pass

    ctx.default_map = options
    ctx.obj = {
        'config': config,
    }



import click

from .._util.format import pretty_table


@click.command()
@click.option('-n', '--namespace', type=click.STRING, show_default=True)
@click.pass_obj
def cli(obj, namespace):
    """List all buckets in namespace
    """
    client = obj['client']

    bucket_request = client.bucket.list(namespace=namespace)
    bucket_list = [(bucket['namespace'], bucket['name'], bucket['owner']) for bucket in bucket_request['object_bucket']]
    headers = ['Namespace', 'Bucket Name', 'Owner']
    table = pretty_table(bucket_list, headers)
    click.echo(table)



import click

from ..._util.core import DynamicMultiCommandFactory

DynamicMultiCommand = DynamicMultiCommandFactory().create(__file__, __package__)


@click.command(cls=DynamicMultiCommand, name='retention')
def cli():
    """Manage bucket retention
    """



import click
from ecsclient.common.exceptions import ECSClientException

from ..._util import types
from ..._util.echo import success
from ..._util.exceptions import EcsmgmtClickException


@click.command()
@click.argument('bucket-name', type=click.STRING)
@click.argument('period', type=types.TIME)
@click.option('-n', '--namespace', type=click.STRING, show_default=True)
@click.pass_obj
def cli(obj, bucket_name, period, namespace):
    """Set bucket retention
    """
    client = obj['client']

    try:
        client.bucket.set_retention(bucket_name=bucket_name, namespace=namespace, period=period)
        success(f'Set retention for bucket "{bucket_name}" to {period} seconds')
    except ECSClientException as e:
        raise EcsmgmtClickException(e.message)



import click

from .._util.format import pretty_info


@click.command()
@click.argument('user-id', type=click.STRING)
@click.option('-n', '--namespace', type=click.STRING, show_default=True)
@click.pass_obj
def cli(obj, user_id, namespace):
    """Get user details
    """
    client = obj['client']

    res = client.object_user.get(user_id=user_id, namespace=namespace)

    click.secho(f'User "{user_id}" info:', bold=True)
    click.echo(pretty_info(res))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ecsmgmt',
 'ecsmgmt._util',
 'ecsmgmt.bucket',
 'ecsmgmt.bucket.acl',
 'ecsmgmt.bucket.retention',
 'ecsmgmt.secret-key',
 'ecsmgmt.user']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML>=6.0,<7.0',
 'click>=8.1.3,<9.0.0',
 'inquirer>=2.10.0,<3.0.0',
 'python-ecsclient>=1.1.12,<2.0.0',
 'tabulate>=0.8.10,<0.9.0']

entry_points = \
{'console_scripts': ['ecsmgmt = ecsmgmt:cli']}

setup_kwargs = {
    'name': 'ecsmgmt-cli',
    'version': '0.4.1',
    'description': 'Small CLI tool for interacting with the ECS Management API',
    'long_description': "# ecsmgmt-cli\n\nSmall CLI tool for interacting with the ECS Management API. ECS is Dell EMC's Object Storage (S3) Solution.\n\n## usage\n\n### config file\n**Warning: It's not recommended to store you're credentials in an plaintext file. If you decide nevertheless to do so, please be shure to limit the access to the config file, for example with `chmod 600 $configfilepath`.**\n\nThe config file is expected to be in the common config directories for the following platforms:\n* unix: `~/.config/ecsmgmt-cli/config.yml`\n* macOS: `~/Library/Application Support/ecsmgmt-cli/config.yml`\n* Windows: `C:\\Users\\<user>\\AppData\\Local\\ecsmgmt-cli\\config.yml`\n\n",
    'author': 'Dominik Rimpf',
    'author_email': 'dev@drimpf.de',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://gitlab.com/domrim/ecsmgmt-cli',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
